*:
    @filter.pyformat:- foo
    content: merged content with all request. this will override content
    foo: $bars <b>{request.path_params.name}!</b>
/{name:str}:
    title: Demo Virtual Page
    content: $This is a <em>virtual page</em> for <b>{request.path_params.name}!</b>
